@@ -9,7 +9,6 @@ MessagesWindow::MessagesWindow(QWidget *parent, QString token) :
     nam(new QNetworkAccessManager(this))
 {
     ui->setupUi(this);
-    setAttribute(Qt::WA_DeleteOnClose);
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
     this->orientationChanged();
 #ifdef Q_WS_MAEMO_5
@@ -70,6 +69,7 @@ void MessagesWindow::onReplyReceived()
         /* Messages are readonly for now... */
         // item->setDeletable(true);
         connect(item, SIGNAL(clicked(QString)), this, SLOT(onMessageClicked(QString)));
+        connect(item, SIGNAL(nameClicked(QString,QString)), this, SLOT(onNameClicked(QString,QString)));
         QString from = jsonData.toMap().value("from").toMap().value("name").toString();
         QString userId = jsonData.toMap().value("from").toMap().value("id").toString();
         QString id = jsonData.toMap().value("id").toString();
@@ -113,3 +113,15 @@ void MessagesWindow::onNewMessageButtonClicked()
     messageComposer->show();
 #endif
 }
+
+void MessagesWindow::onNameClicked(QString id, QString name)
+{
+    ProfileWindow *profile = new ProfileWindow(this, accessToken);
+    profile->browseProfile(id);
+    profile->setWindowTitle(name);
+#ifdef Q_WS_S60
+    profile->showMaximized();
+#else
+    profile->show();
+#endif
+}
