@@ -1,5 +1,6 @@
 #include "messageview.h"
 #include "ui_messageview.h"
+#include "profilewindow.h"
 
 MessageView::MessageView(QWidget *parent, QString token) :
     QMainWindow(parent),
@@ -56,6 +57,7 @@ void MessageView::onReplyReceived()
 
     QVariant jsonData = this->reply->data();
     NewsFeedPost *mainMessage = new NewsFeedPost(this, accessToken, qfacebook, nam);
+    connect(mainMessage, SIGNAL(nameClicked(QString,QString)), this, SLOT(onNameClicked(QString,QString)));
     QString from = jsonData.toMap().value("from").toMap().value("name").toString();
     QString fromId = jsonData.toMap().value("from").toMap().value("id").toString();
     QString message = jsonData.toMap().value("message").toString();
@@ -76,6 +78,7 @@ void MessageView::onReplyReceived()
     listData = jsonData.toMap().value("comments").toMap().value("data").toList();
     foreach(jsonData, listData) {
         NewsFeedPost *post = new NewsFeedPost(ui->repliesWidget, accessToken, qfacebook, nam);
+        connect(post, SIGNAL(nameClicked(QString,QString)), this, SLOT(onNameClicked(QString,QString)));
         post->setMessageMode(true);
         QString name = jsonData.toMap().value("from").toMap().value("name").toString();
         QString userId = jsonData.toMap().value("from").toMap().value("id").toString();
@@ -108,3 +111,15 @@ void MessageView::onReplyReceived()
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 #endif
 }
+
+void MessageView::onNameClicked(QString id, QString name)
+{
+    ProfileWindow *profile = new ProfileWindow(this, accessToken);
+    profile->browseProfile(id);
+    profile->setWindowTitle(name);
+#ifdef Q_WS_S60
+    profile->showMaximized();
+#else
+    profile->show();
+#endif
+}
