@@ -6,7 +6,9 @@ NewsFeedWindow::NewsFeedWindow(QWidget *parent, QString token) :
     ui(new Ui::NewsFeedWindow),
     accessToken(token),
     qfacebook(new QFacebook(token, this)),
-    nam(new QNetworkAccessManager(this))
+    nam(new QNetworkAccessManager(this)),
+    m_loadingWidget(0),
+    m_statusUpdateDialog(0)
 {
     ui->setupUi(this);
 #ifdef Q_WS_MAEMO_5
@@ -39,13 +41,18 @@ void NewsFeedWindow::orientationChanged()
 
 void NewsFeedWindow::onNewStatusUpdateButtonClicked()
 {
-    NewStatusUpdateDialog *dialog = new NewStatusUpdateDialog(this);
-    connect(dialog, SIGNAL(postUpdate(QString,QString,QString)), this, SLOT(postUpdate(QString,QString,QString)));
+    if (!m_statusUpdateDialog) {
+        m_statusUpdateDialog = new NewStatusUpdateDialog(this);
+        connect(m_statusUpdateDialog, SIGNAL(postUpdate(QString,QString,QString)), this, SLOT(postUpdate(QString,QString,QString)));
+    }
 #ifdef Q_WS_S60
-    dialog->showMaximized();
+    m_statusUpdateDialog->showMaximized();
 #else
-    dialog->show();
+    m_statusUpdateDialog->show();
 #endif
+
+    if (!m_statusUpdateDialog->isActiveWindow())
+        m_statusUpdateDialog->activateWindow();
 }
 
 void NewsFeedWindow::postUpdate(QString text, QString link, QString video)
@@ -80,8 +87,12 @@ void NewsFeedWindow::onStatusUpdateReplyFinished()
 
 void NewsFeedWindow::updateNewsFeed()
 {
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#else
     m_loadingWidget = new LoadingWidget(this);
     m_loadingWidget->setLoading(true);
+#endif
 
     QString limit = QSettings().value("main/newsFeedLimit", "80").toString();
     this->reply = qfacebook->getConnections("me", QString("home&limit=%1").arg(limit));
@@ -106,13 +117,15 @@ void NewsFeedWindow::onNewsFeedItemParsed(QString fromName, QString fromId, bool
                                           QString message, QString icon, QString time, QString link,
                                           QString linkName, QString linkDescription, QString linkPicture,
                                           QString toId, QString toName, bool meLikesThis, QString commentsCount,
-                                          QString likesCount, QString postId)
+                                          QString likesCount, QString postId, QString postType, QString objectId)
 {
     NewsFeedPost *post = new NewsFeedPost(ui->postsWidget, accessToken, qfacebook, nam);
     connect(post, SIGNAL(commentButtonClicked(QString,QString,QString)),
             this, SLOT(onCommentButtonClicked(QString,QString,QString)));
     connect(post, SIGNAL(nameClicked(QString,QString)), this, SLOT(onNameClicked(QString,QString)));
     post->getPixmapFromUrl(QString("http://graph.facebook.com/%1/picture").arg(fromId));
+    post->setType(postType);
+    post->setObjectId(objectId);
     post->setId(postId);
     post->setName(fromName);
     post->setUserId(fromId);
@@ -163,15 +176,24 @@ void NewsFeedWindow::onReplyFinished()
     connect(parser, SIGNAL(finished()), parser, SLOT(deleteLater()));
     connect(thread, SIGNAL(finished()), thread, SLOT(deleteLater()));
     connect(parser, SIGNAL(feedItemParsed(QString,QString,bool,QString,QString,QString,QString,
-                                          QString,QString,QString,QString,QString,bool,QString,QString,QString)), this,
+                                          QString,QString,QString,QString,QString,bool,QString,QString,QString,QString,QString)), this,
             SLOT(onNewsFeedItemParsed(QString,QString,bool,QString,QString,QString,QString,QString,QString,
-                                      QString,QString,QString,bool,QString,QString,QString)));
+                                      QString,QString,QString,bool,QString,QString,QString,QString,QString)));
     connect(thread, SIGNAL(started()), parser, SLOT(start()));
-    connect(parser, SIGNAL(finished()), m_loadingWidget, SLOT(hideWidget()));
+    connect(parser, SIGNAL(finished()), this, SLOT(onParserThreadFinished()));
 
     thread->start();
 }
 
+void NewsFeedWindow::onParserThreadFinished()
+{
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+#else
+    m_loadingWidget->hideWidget();
+#endif
+}
+
 void NewsFeedWindow::onCommentButtonClicked(QString id, QString comments, QString likes)
 {
     SinglePostWindow *window = new SinglePostWindow(this, accessToken);
@@ -184,6 +206,14 @@ void NewsFeedWindow::onCommentButtonClicked(QString id, QString comments, QStrin
 #endif
 }
 
+void NewsFeedWindow::keyPressEvent(QKeyEvent *e)
+{
+    if ((e->modifiers() & Qt::ControlModifier) && e->key() == Qt::Key_Q) {
+        setAttribute(Qt::WA_DeleteOnClose);
+        this->close();
+    }
+}
+
 NewsFeedParser::NewsFeedParser(QVariant jsonData, QString accessToken)
 {
     this->nam = new QNetworkAccessManager();
@@ -207,25 +237,33 @@ void NewsFeedParser::start()
         QString message = jsonData.toMap().value("message").toString();
         QString icon = jsonData.toMap().value("icon").toString();
         QString time = jsonData.toMap().value("created_time").toString();
-        QString link = jsonData.toMap().value("link").toString();
+        QString postType = jsonData.toMap().value("type").toString();
         QString linkName;
         QString linkDescription;
         QString linkPicture;
         QString toId;
         QString toName;
 
-        if (link.isEmpty())
-            link = jsonData.toMap().value("source").toString();
+        QString link = jsonData.toMap().value("link").toString();
+        QString sourceLink = jsonData.toMap().value("source").toString();
+        if (link.isEmpty() || (postType == "video" && sourceLink.contains("fbcdn")))
+            link = sourceLink;
         if (!link.isEmpty()) {
-            linkName = jsonData.toMap().value("name").toString();
-            linkDescription = jsonData.toMap().value("description").toString();
+            linkName = jsonData.toMap().value("name").toString(),
+            linkDescription = jsonData.toMap().value("description").toString(),
             linkPicture = jsonData.toMap().value("picture").toString();
         }
         QVariantList toVariant = jsonData.toMap().value("to").toMap().value("data").toList();
         if (!toVariant.isEmpty()) {
-            QVariant to = toVariant.first();
-            if (message.contains(to.toString()) && toVariant.count() > 1)
-                to = toVariant.at(1);
+            QVariant to = toVariant.last();
+
+            foreach (QVariant taggedName, toVariant) {
+                QString name = taggedName.toMap().value("name").toString();
+                QString id = taggedName.toMap().value("id").toString();
+                if (message.contains(name)) {
+                    message = message.replace(name, QString("<a href=\"profile://%1\">%2</a>").arg(id, name));
+                }
+            }
 
             toId = to.toMap().value("id").toString();
             toName = to.toMap().value("name").toString();
@@ -252,9 +290,10 @@ void NewsFeedParser::start()
             comments = "0";
 
         QString postId = jsonData.toMap().value("id").toString();
+        QString objectId = jsonData.toMap().value("object_id").toString();
         // Set parsed data
         emit feedItemParsed(name, userId, isDeletable, message, icon, time, link, linkName, linkDescription, linkPicture,
-                            toId, toName, meLikesThis, comments, likesCount, postId);
+                            toId, toName, meLikesThis, comments, likesCount, postId, postType, objectId);
     }
     emit finished();
 }
