@@ -9,7 +9,10 @@
 #include <QDebug>
 #include <QList>
 #include <QMessageBox>
+#include <QTimer>
+#include <qfacebook.h>
 #include <QDesktopWidget>
+#include <qjson/serializer.h>
 #include "widgets/notificationitem.h"
 #include "profilewindow.h"
 #include "singlepostwindow.h"
@@ -45,18 +48,24 @@ private:
     QNetworkAccessManager* nam;
     QNetworkReply *reply;
     QNetworkReply *countReply;
+    QNetworkReply *markReadReply;
+    QFacebook *qfacebook;
     QMap <QString, QString> parseNotification(QXmlStreamReader &xml);
+    QByteArray m_notifications;
     void addElementDataToMap(QXmlStreamReader& xml, QMap<QString, QString>& map) const;
     void addNotificationsToUi(QList< QMap<QString,QString> >& notifications);
     QList <NotificationItem*> notificationItems;
     int unreadCount;
     bool isFetching;
+    QList <NotificationItem*> m_unreadNotifications;
 
 private slots:
     void onNotificationsListReceived();
     void onGotNotificationsCount();
     void orientationChanged();
     void onNotificationClicked(NotificationItem*);
+    void markRead();
+    void onMarkedAsRead(NotificationItem *item);
 };
 
 #endif // NOTIFICATIONSDIALOG_H
