@@ -18,14 +18,21 @@ PlacesWindow::PlacesWindow(QWidget *parent, QString token) :
     setAttribute(Qt::WA_DeleteOnClose);
 #ifdef MOBILITY
     if (source) {
-        source->setPreferredPositioningMethods(QGeoPositionInfoSource::SatellitePositioningMethods);
-        source->setUpdateInterval(10000);
+        source->setUpdateInterval(5000);
         connect(source, SIGNAL(positionUpdated(QGeoPositionInfo)), this, SLOT(onPositionUpdated(QGeoPositionInfo)));
         source->startUpdates();
+        longitude = source->lastKnownPosition().coordinate().longitude();
+        latitude = source->lastKnownPosition().coordinate().latitude();
     }
 #endif
     this->updateRecentCheckins();
     connect(ui->actionCheck_in, SIGNAL(triggered()), this, SLOT(checkIn()));
+    bool whiteMode = QSettings().value("main/white-mode", false).toBool();
+    if (whiteMode) {
+        QPalette p(palette());
+        p.setColor(QPalette::Background, QColor(220, 225, 235));
+        setPalette(p);
+    }
 }
 
 PlacesWindow::~PlacesWindow()
@@ -110,15 +117,34 @@ void PlacesWindow::checkIn()
     connect(dialog, SIGNAL(placeSelected(QString,QString,QString,QString)),
             this, SLOT(onPlaceSelected(QString,QString,QString,QString)));
     dialog->setCoordinates(longitude, latitude);
+#ifdef Q_WS_S60
+    dialog->showMaximized();
+#else
     dialog->show();
+#endif
 }
 
 void PlacesWindow::onPlaceSelected(QString name, QString id, QString longitude, QString latitude)
 {
-    qDebug() << name << id << longitude << latitude;
     CheckinWindow *checkInWindow = new CheckinWindow(this, accessToken);
     checkInWindow->setLocation(name, id, longitude, latitude);
+#ifdef Q_WS_S60
+    checkInWindow->showMaximized();
+#else
     checkInWindow->show();
+#endif
+}
+
+void PlacesWindow::onNameClicked(QString id, QString name)
+{
+    ProfileWindow *profile = new ProfileWindow(this, accessToken);
+    profile->browseProfile(id);
+    profile->setWindowTitle(name);
+#ifdef Q_WS_S60
+    profile->showMaximized();
+#else
+    profile->show();
+#endif
 }
 
 void PlacesWindow::closeEvent(QCloseEvent *)
