@@ -2,7 +2,7 @@
 #include "ui_profilewindow.h"
 #include "albumswindow.h"
 
-ProfileWindow::ProfileWindow(QWidget *parent, QString token) :
+ProfileWindow::ProfileWindow(QWidget *parent, QString token, ProfileTypes profileType) :
     QMainWindow(parent),
     ui(new Ui::ProfileWindow),
     qfacebook(new QFacebook(token, this)),
@@ -13,7 +13,13 @@ ProfileWindow::ProfileWindow(QWidget *parent, QString token) :
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
-    //connect(ui->writeOnWallEdit, SIGNAL(), this, SLOT(onTextBoxClicked()));
+    m_profileType = profileType;
+    if (profileType == ProfileWindow::GroupProfile) {
+        ui->menuOptions->addAction(tr("Members"), this, SLOT(showFriends()));
+    } else if (profileType == ProfileWindow::FriendProfile) {
+        // Argh, facebook's public API sucks! You can't browse someone's friends with it :/
+        // ui->menuOptions->addAction(tr("Friends"), this, SLOT(showFriends()));
+    }
     connect(ui->writeOnWallEdit, SIGNAL(clicked()), this, SLOT(onTextBoxClicked()));
     connect(ui->actionRefresh, SIGNAL(triggered()), this, SLOT(updateProfile()));
     connect(ui->userAvatar, SIGNAL(clicked()), this, SLOT(onAvatarClicked()));
@@ -42,10 +48,11 @@ void ProfileWindow::orientationChanged()
 
 void ProfileWindow::browseProfile(QString id)
 {
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#endif
     this->profileId = id;
-    if (id == "me")
-        ui->menuOptions->removeAction(ui->actionPoke);
-    else
+    if (id != "me")
         setAttribute(Qt::WA_DeleteOnClose);
     QString url = QString("https://graph.facebook.com/%1/picture&access_token=%2&type=normal").arg(id, accessToken);
     this->avatarReply = nam->get(QNetworkRequest(url));
@@ -60,6 +67,69 @@ void ProfileWindow::browseProfile(QString id)
         connect(reply, SIGNAL(finished()), this, SLOT(onReplyReceived()));
 }
 
+void ProfileWindow::showFriends()
+{
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#endif
+    QString connection;
+    if (m_profileType == ProfileWindow::FriendProfile)
+        connection = "friends";
+    else if (m_profileType == ProfileWindow::GroupProfile)
+        connection = "members";
+    friendsReply = qfacebook->getConnections(profileId, connection);
+    if (friendsReply)
+        connect(friendsReply, SIGNAL(finished()), this, SLOT(onGotFriendsList()));
+}
+
+void ProfileWindow::onGotFriendsList()
+{
+    QDialog *dialog = new QDialog(this);
+    QVBoxLayout *layout = new QVBoxLayout(dialog);
+    QListWidget *listWidget = new QListWidget(this);
+    listWidget->setSortingEnabled(true);
+    connect(listWidget, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(onFriendClicked(QListWidgetItem*)));
+    layout->addWidget(listWidget);
+    dialog->setLayout(layout);
+#ifdef Q_WS_MAEMO_5
+    dialog->setMinimumHeight(600);
+#endif
+
+    QVariant jsonData = friendsReply->data();
+    qDebug() << jsonData;
+    QVariantList listData = jsonData.toMap().value("data").toList();
+    foreach (jsonData, listData) {
+        QListWidgetItem *item = new QListWidgetItem(listWidget);
+        item->setData(Qt::UserRole, jsonData.toMap().value("id").toString());
+        item->setText(jsonData.toMap().value("name").toString());
+    }
+
+    if (m_profileType == ProfileWindow::FriendProfile)
+        dialog->setWindowTitle(tr("Friends"));
+    else if (m_profileType == ProfileWindow::GroupProfile)
+        dialog->setWindowTitle(tr("Members"));
+    dialog->setAttribute(Qt::WA_DeleteOnClose);
+    dialog->show();
+
+    friendsReply->deleteLater();
+    friendsReply = 0;
+#ifdef Q_WS_MAEMO_5
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+#endif
+}
+
+void ProfileWindow::onFriendClicked(QListWidgetItem *item)
+{
+    ProfileWindow *profile = new ProfileWindow(this, accessToken);
+    profile->setWindowTitle(item->text());
+    profile->browseProfile(item->data(Qt::UserRole).toString());
+#ifdef Q_WS_S60
+    profile->showMaximized();
+#else
+    profile->show();
+#endif
+}
+
 void ProfileWindow::onInfoReplyReceived()
 {
     if (this->infoReply->error() != QNetworkReply::NoError) {
@@ -186,9 +256,13 @@ void ProfileWindow::onReplyReceived()
         QString message = jsonData.toMap().value("message").toString();
         QString icon = jsonData.toMap().value("icon").toString();
         QString time = jsonData.toMap().value("created_time").toString();
+        QString objectId = jsonData.toMap().value("object_id").toString();
+        QString objectType = jsonData.toMap().value("type").toString();
         QString link = jsonData.toMap().value("link").toString();
-        if (link.isEmpty())
-            link = jsonData.toMap().value("source").toString();
+        QString sourceLink = jsonData.toMap().value("source").toString();
+        QString postType = jsonData.toMap().value("type").toString();
+        if (link.isEmpty() || (postType == "video" && sourceLink.contains("fbcdn")))
+            link = sourceLink;
         if (!link.isEmpty()) {
             post->addLink(link,
                           jsonData.toMap().value("name").toString(),
@@ -197,9 +271,16 @@ void ProfileWindow::onReplyReceived()
         }
         QVariantList toVariant = jsonData.toMap().value("to").toMap().value("data").toList();
         if (!toVariant.isEmpty()) {
-            QVariant to = toVariant.first();
-            if (message.contains(to.toMap().value("name").toString()) && toVariant.count() > 1)
-                to = toVariant.at(1);
+            QVariant to = toVariant.last();
+
+            foreach (QVariant taggedName, toVariant) {
+                QString name = taggedName.toMap().value("name").toString();
+                QString id = taggedName.toMap().value("id").toString();
+                if (message.contains(name)) {
+                    message.replace(name, QString("<a href=\"profile://%1\">%2</a>").arg(id, name));
+                }
+            }
+            post->setMessage(message);
 
             QString toId = to.toMap().value("id").toString();
             QString toName = to.toMap().value("name").toString();
@@ -214,15 +295,15 @@ void ProfileWindow::onReplyReceived()
 
         // Check if the currently logged in user likes the post
         QVariantList likes = jsonData.toMap().value("likes").toMap().value("data").toList();
-        bool meLikesThis = false;
         QString myId = QSettings().value("main/myId").toString();
+        bool meLikesThis = false;
         foreach (QVariant likeId, likes) {
             QVariantMap map = likeId.value<QVariantMap>();
             QString likerId = map.value("id").toString();
-            if (likerId.contains(myId))
+            if (likerId.contains(myId)) {
                 meLikesThis = true;
-            else
-                meLikesThis = false;
+                break;
+            }
         }
 
         // Get like and comment count.
@@ -235,6 +316,8 @@ void ProfileWindow::onReplyReceived()
 
         // Set parsed data
         post->setName(name);
+        post->setObjectId(objectId);
+        post->setType(objectType);
         post->setMessage(message);
         post->setId(jsonData.toMap().value("id").toString());
         post->setUserId(userId);
