@@ -12,6 +12,7 @@ SinglePostWindow::SinglePostWindow(QWidget *parent, QString token) :
     ui->setupUi(this);
     connect(ui->commentButton, SIGNAL(clicked()), this, SLOT(onPostButtonClicked()));
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
+    connect(ui->count, SIGNAL(linkActivated(QString)), this, SLOT(onLinkActivated(QString)));
     this->orientationChanged();
     gotMainPost = false;
     myId = QSettings().value("main/myId").toString();
@@ -64,14 +65,65 @@ void SinglePostWindow::setCountLabel(QString comments, QString likes)
         ui->count->setText(text);
         return;
     }
-    text.append(" " + tr("and") + " " + likes + " ");
+    //<a href=\"%1\">%2</a>
+    text.append(" " + tr("and") + " " + QString("<a href=\"%1\">").arg(QString("likes://" + postId)) + likes + " ");
     if (likes.toInt() == 1)
         text.append(tr("like"));
     else
         text.append(tr("likes"));
+    text.append("</a>");
     ui->count->setText(text);
 }
 
+void SinglePostWindow::onLinkActivated(QString url)
+{
+    if (url.contains("likes://")) {
+        ui->count->blockSignals(true);
+        QString id = url.remove("likes://");
+        likersReply = qfacebook->getConnections(id, "likes");
+        if (likersReply)
+            connect(likersReply, SIGNAL(finished()), this, SLOT(onGotLikers()));
+    }
+}
+
+void SinglePostWindow::onGotLikers()
+{
+    ui->count->blockSignals(false);
+    QVariant likersData = likersReply->data();
+    QDialog *likersDialog = new QDialog(this);
+#ifdef Q_WS_MAEMO_5
+    likersDialog->setMinimumHeight(800);
+#endif
+    likersDialog->setWindowTitle(tr("People who like this"));
+    QVBoxLayout *layout = new QVBoxLayout(likersDialog);
+    QListWidget *listWidget = new QListWidget(likersDialog);
+    connect(listWidget, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(onLikerActivated(QListWidgetItem*)));
+    layout->addWidget(listWidget);
+    QVariantList likersList = likersData.toMap().value("data").toList();
+    foreach (QVariant liker, likersList) {
+        QListWidgetItem *item = new QListWidgetItem(listWidget);
+        item->setData(Qt::UserRole, liker.toMap().value("id").toString());
+        item->setText(liker.toMap().value("name").toString());
+    }
+#ifdef Q_WS_60
+    likersDialog->showMaximized();
+#else
+    likersDialog->show();
+#endif
+}
+
+void SinglePostWindow::onLikerActivated(QListWidgetItem *item)
+{
+    ProfileWindow *profile = new ProfileWindow(this, accessToken);
+    profile->setWindowTitle(item->text());
+    profile->browseProfile(item->data(Qt::UserRole).toString());
+#ifdef Q_WS_S60
+    profile->showMaximized();
+#else
+    profile->show();
+#endif
+}
+
 void SinglePostWindow::onReplyReceived()
 {
     if (!posts.isEmpty()) {
@@ -104,29 +156,43 @@ void SinglePostWindow::onReplyReceived()
 
     QString message = jsonData.toMap().value("message").toString();
     QString time = jsonData.toMap().value("created_time").toString();
-    QString link = jsonData.toMap().value("link").toString();
     QString linkName;
     QString linkDescription;
     QString linkPicture;
-    if (link.isEmpty())
-        link = jsonData.toMap().value("source").toString();
+    QString link = jsonData.toMap().value("link").toString();
+    QString sourceLink = jsonData.toMap().value("source").toString();
+    QString postType = jsonData.toMap().value("type").toString();
+    if (link.isEmpty() || (postType == "video" && sourceLink.contains("fbcdn")))
+        link = sourceLink;
     QString likesCount = jsonData.toMap().value("likes").toMap().value("count").toString();
     if (likesCount.isEmpty())
         likesCount = "0";
     if (link.isEmpty())
         link = jsonData.toMap().value("source").toString();
-    if (!link.isEmpty()) {
-        linkName = jsonData.toMap().value("name").toString();
-        linkDescription = jsonData.toMap().value("description").toString();
-        linkPicture = jsonData.toMap().value("picture").toString();
+    QVariantList likes = jsonData.toMap().value("likes").toMap().value("data").toList();
+    QString myId = QSettings().value("main/myId").toString();
+    bool meLikesThis = false;
+    foreach (QVariant likeId, likes) {
+        QVariantMap map = likeId.value<QVariantMap>();
+        QString likerId = map.value("id").toString();
+        if (likerId.contains(myId)) {
+            meLikesThis = true;
+            break;
+        }
     }
-    QVariantList toVariant = jsonData.toMap().value("to").toMap().value("data").toList();
     QString toId;
     QString toName;
+    QVariantList toVariant = jsonData.toMap().value("to").toMap().value("data").toList();
     if (!toVariant.isEmpty()) {
-        QVariant to = toVariant.first();
-        if (message.contains(to.toString()) && toVariant.count() > 1)
-            to = toVariant.at(1);
+        QVariant to = toVariant.last();
+
+        foreach (QVariant taggedName, toVariant) {
+            QString name = taggedName.toMap().value("name").toString();
+            QString id = taggedName.toMap().value("id").toString();
+            if (message.contains(name)) {
+                message = message.replace(name, QString("<a href=\"profile://%1\">%2</a>").arg(id, name));
+            }
+        }
 
         toId = to.toMap().value("id").toString();
         toName = to.toMap().value("name").toString();
@@ -136,7 +202,15 @@ void SinglePostWindow::onReplyReceived()
         NewsFeedPost *post = new NewsFeedPost(this, accessToken, qfacebook, nam);
         connect(post, SIGNAL(nameClicked(QString,QString)), this, SLOT(onNameClicked(QString,QString)));
         connect(post, SIGNAL(destroyed()), this, SLOT(close()));
+        if (!link.isEmpty()) {
+            post->addLink(link,
+                          jsonData.toMap().value("name").toString(),
+                          jsonData.toMap().value("description").toString(),
+                          jsonData.toMap().value("picture").toString());
+        }
         post->setCommentMode(true);
+        post->setType(postType);
+        post->setLikedByMe(meLikesThis);
         post->setDeletable(deletable);
         post->setMessage(message);
         post->setName(name);
@@ -168,29 +242,45 @@ void SinglePostWindow::onReplyReceived()
         QString icon = jsonData.toMap().value("icon").toString();
         QString time = jsonData.toMap().value("created_time").toString();
         QString link = jsonData.toMap().value("link").toString();
+        if (link.isEmpty())
+            link = jsonData.toMap().value("source").toString();
         if (!link.isEmpty()) {
-            if (!message.isEmpty())
-                message.append("\n");
-            message.append(QString("<a href=\"%1\">%1</a>").arg(link) + "\n\n");
-            message.append(jsonData.toMap().value("name").toString() + "\n");
-            message.append(jsonData.toMap().value("caption").toString() + "\n");
-            message.append(jsonData.toMap().value("description").toString() + "\n");
+            post->addLink(link,
+                          jsonData.toMap().value("name").toString(),
+                          jsonData.toMap().value("description").toString(),
+                          jsonData.toMap().value("picture").toString());
         }
+
+        QVariantList toVariant = jsonData.toMap().value("to").toMap().value("data").toList();
+        if (!toVariant.isEmpty()) {
+            QVariant to = toVariant.first();
+            if (message.contains(to.toMap().value("name").toString()) && toVariant.count() > 1)
+                to = toVariant.at(1);
+
+            foreach (QVariant taggedName, toVariant) {
+                QString name = taggedName.toMap().value("name").toString();
+                QString id = taggedName.toMap().value("id").toString();
+                if (message.contains(name)) {
+                    message.replace(name, QString("<a href=\"profile://%1\">%2</a>").arg(id, name));
+                }
+            }
+            post->setMessage(message);
+        }
+
         // Check if the currently logged in user likes the post
         QVariantList likes = jsonData.toMap().value("likes").toMap().value("data").toList();
         bool meLikesThis = false;
-        QString myId = QSettings().value("main/myId").toString();
         foreach (QVariant likeId, likes) {
             QVariantMap map = likeId.value<QVariantMap>();
             QString likerId = map.value("id").toString();
-            if (likerId.contains(myId))
+            if (likerId.contains(myId)) {
                 meLikesThis = true;
-            else
-                meLikesThis = false;
+                break;
+            }
         }
 
         // Get like and comment count.
-        QString likesCount = jsonData.toMap().value("likes").toMap().value("count").toString();
+        QString likesCount = jsonData.toMap().value("likes").toString();
         if (likesCount.isEmpty())
             likesCount = "0";
 
@@ -241,11 +331,13 @@ void SinglePostWindow::onPostButtonClicked()
     if (this->commentReply)
         connect(commentReply, SIGNAL(finished()), this, SLOT(onCommentReplyReceived()));
     ui->replyEdit->setEnabled(false);
+    ui->commentButton->setEnabled(false);
 }
 
 void SinglePostWindow::onCommentReplyReceived()
 {
     ui->replyEdit->setEnabled(true);
+    ui->commentButton->setEnabled(true);
 
     if (this->commentReply->error() != QNetworkReply::NoError) {
         qDebug() << "Failed to post comment!";
@@ -265,5 +357,7 @@ void SinglePostWindow::onCommentReplyReceived()
     QMaemo5InformationBox::information(this, tr("Comment posted"));
 #endif
 
+    this->commentReply->deleteLater();
+
     this->loadPost(this->postId);
 }
